@@ -31,6 +31,12 @@ def add_taskbar(window):
     window.after(10, lambda: window.wm_deiconify())
 
 
+def window_centre(window: tk.Tk):
+    x = window.winfo_screenwidth() / 2 - window.winfo_width() / 2
+    y = window.winfo_screenheight() / 2 - window.winfo_height() / 2
+    window.geometry(f"{window.winfo_width()}x{window.winfo_height()}+{round(x)}+{round(y)}")
+
+
 class DevAccumulatorButton(tk.Button):
     def __init__(self):
         pass
@@ -331,6 +337,7 @@ class DevTitleBar(tk.Frame):
                 self.maxbutton.configure(command=self.widget_max)
             if self.min:
                 self.minbutton.configure(command=self.widget_min)
+        self.bind("<Double-Button-1>", lambda evt: self.widget_max())
 
     def add_title(self, title: str = "", title_bg="#ffffff", title_fg="#000000"):
         self.title = tk.Label(self, text=title, background=title_bg)
@@ -399,7 +406,7 @@ class DevToplevel(tk.Toplevel):
     def __init__(self):
         super(DevToplevel, self).__init__()
         self.title("tkDev")
-        self.geometry("400x300")
+        self.geometry("500x500")
         self.configure(background="#f0f0f0")
 
     def wm_statusBar(self, statusBar: tk.Widget):
@@ -409,11 +416,12 @@ class DevToplevel(tk.Toplevel):
 
     statusbar = wm_statusBar
 
-    def wm_titleBar(self, titleBar: tk.Label):
+    def wm_titleBar(self, titleBar: tk.Label, showtask: bool = True):
         from ctypes import windll
         self.minsize(100, 30)
         self.overrideredirect(True)
-        self.after(10, lambda: add_taskbar(self))
+        if showtask:
+            self.after(10, lambda: add_taskbar(self))
         self._titlebar = titleBar
         self._titlebar.pack(fill=tk.X, side=tk.TOP)
         DevDrag(self._titlebar, self, True)
@@ -426,7 +434,7 @@ class DevWindow(tk.Tk):
     def __init__(self):
         super(DevWindow, self).__init__()
         self.title("tkDev")
-        self.geometry("400x300")
+        self.geometry("500x500")
         self.configure(background="#f0f0f0")
 
     def wm_statusBar(self, statusBar: tk.Widget):
@@ -436,11 +444,12 @@ class DevWindow(tk.Tk):
 
     statusbar = wm_statusBar
 
-    def wm_titleBar(self, titleBar: tk.Label):
+    def wm_titleBar(self, titleBar: tk.Label, showtask: bool = True):
         from ctypes import windll
         self.minsize(100, 30)
         self.overrideredirect(True)
-        self.after(10, lambda: add_taskbar(self))
+        if showtask:
+            self.after(10, lambda: add_taskbar(self))
         self._titlebar = titleBar
         self._titlebar.pack(fill=tk.X, side=tk.TOP)
         DevDrag(self._titlebar, self, True)
@@ -448,6 +457,11 @@ class DevWindow(tk.Tk):
 
     titlebar = wm_titleBar
 
+    def wm_centre(self):
+        self.after(1, lambda evt=None: window_centre(self))
+
+    centre = wm_centre
+
 
 if __name__ == '__main__':
     Root = DevWindow()
@@ -455,4 +469,5 @@ if __name__ == '__main__':
     Root.titlebar(TitleBar)
     AppBar = DevAppBar(Root, title="Hello World")
     AppBar.show()
+    Root.centre()
     Root.mainloop()
